@@ -1,6 +1,6 @@
 /* Custom error logging system
  *
- * Copyright (C) 2010-2020  Joachim Nilsson <troglobit@gmail.com>
+ * Copyright (C) 2010-2021  Joachim Wiberg <troglobit@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,14 +25,20 @@
 #include <stdarg.h>
 #include "os.h"
 
+#ifndef MAX_LOG_LEVEL
+#define MAX_LOG_LEVEL LOG_DEBUG
+#endif
+
 void log_init  (char *ident, int log, int bg);
 void log_exit  (void);
 
 int  log_level (char *level);
 
-void logit     (int prio, const char *fmt, ...);
+void logitf     (int prio, const char *fmt, ...);
 void vlogit    (int prio, const char *fmt, va_list args);
 
+#define logit(p, ...) do if ((p) <= MAX_LOG_LEVEL) logitf((p), __VA_ARGS__); while (0)
+
 #endif /* INADYN_LOG_H_ */
 
 /**
