@@ -63,6 +63,7 @@ static ddns_system_t ovh = {
 	.server_url   = "/nic/update"
 };
 
+
 static ddns_system_t strato = {
 	.name         = "default@strato.com",
 
@@ -80,7 +81,7 @@ static ddns_system_t strato = {
 static int request(ddns_t *ctx, ddns_info_t *info, ddns_alias_t *alias)
 {
 	return snprintf(ctx->request_buf, ctx->request_buflen,
-			CHANGEIP_UPDATE_IP_HTTP_REQUEST,
+			info->system->server_req,
 			info->server_url,
 			alias->name,
 			alias->address,
@@ -96,9 +97,11 @@ static int response(http_trans_t *trans, ddns_info_t *info, ddns_alias_t *alias)
 
 PLUGIN_INIT(plugin_init)
 {
-	plugin_register(&plugin);
-	plugin_register(&ovh);
-	plugin_register(&strato);
+	plugin_register(&plugin, CHANGEIP_UPDATE_IP_HTTP_REQUEST);
+	plugin_register(&ovh, CHANGEIP_UPDATE_IP_HTTP_REQUEST);
+	plugin_register_v6(&ovh, CHANGEIP_UPDATE_IP_HTTP_REQUEST);
+	plugin_register(&strato, CHANGEIP_UPDATE_IP_HTTP_REQUEST);
+	plugin_register_v6(&strato, CHANGEIP_UPDATE_IP_HTTP_REQUEST);
 }
 
 PLUGIN_EXIT(plugin_exit)
