@@ -23,22 +23,6 @@
 
 #include "plugin.h"
 
-/*
- * dyndns.org specific update address format
- *
- * Also applies to other dyndns2 api compatible services, like:
- * DNS-O-Matic, no-ip, 3322, HE and nsupdate.info.
- */
-#define DYNDNS_UPDATE_IP_HTTP_REQUEST					\
-	"GET %s?"							\
-	"hostname=%s&"							\
-	"myip=%s"							\
-	"%s "      							\
-	"HTTP/1.0\r\n"							\
-	"Host: %s\r\n"							\
-	"Authorization: Basic %s\r\n"					\
-	"User-Agent: %s\r\n\r\n"
-
 /*
  * DynDNS request composer -- common to many other DDNS providers as well
  */
@@ -50,7 +34,7 @@ int common_request(ddns_t *ctx, ddns_info_t *info, ddns_alias_t *alias)
 		strlcpy(wildcard, "&wildcard=ON", sizeof(wildcard));
 
 	return snprintf(ctx->request_buf, ctx->request_buflen,
-			DYNDNS_UPDATE_IP_HTTP_REQUEST,
+			info->system->server_req,
 			info->server_url,
 			alias->name,
 			alias->address,
@@ -73,19 +57,22 @@ int common_response(http_trans_t *trans, ddns_info_t *info, ddns_alias_t *alias)
 
 	DO(http_status_valid(trans->status));
 
-	if (strstr(body, "good") || strstr(body, "nochg"))
+	if (strstr(body, "good") || strstr(body, "nochg")  || strstr(body, "OK"))
 		return 0;
 
-	if (strstr(body, "dnserr") || strstr(body, "911"))
+	if (strstr(body, "dnserr") || strstr(body, "911") || strstr(body, "abuse"))
 		return RC_DDNS_RSP_RETRY_LATER;
 
-	if (strstr(body, "badauth"))
+	if (strstr(body, "badauth") || strstr(body, "!donator"))
 		return RC_DDNS_RSP_AUTH_FAIL;
 
 	/* Loopia responds "[200 OK] nohost" when no DNS record exists */
 	if (strstr(body, "nohost"))
 		return RC_DDNS_RSP_NOHOST;
 
+	if (strstr(body, "nofqdn"))
+		return RC_DDNS_RSP_NOHOST;
+
 	return RC_DDNS_RSP_NOTOK;
 }
 
