@@ -39,7 +39,20 @@ static ddns_system_t plugin = {
 	.request      = (req_fn_t)request,
 	.response     = (rsp_fn_t)response,
 
-	.checkip_name = "wtfismyip.com",
+	.checkip_name = "ipv4.wtfismyip.com",
+	.checkip_url  = "/text",
+
+	.server_name  = "homeserver.gira.de",
+	.server_url   = "/hsdyndns.php"
+};
+
+static ddns_system_t plugin_v6 = {
+	.name         = "ipv6@gira.de",
+
+	.request      = (req_fn_t)request,
+	.response     = (rsp_fn_t)response,
+
+	.checkip_name = "ipv6@wtfismyip.com",
 	.checkip_url  = "/text",
 
 	.server_name  = "homeserver.gira.de",
@@ -49,7 +62,7 @@ static ddns_system_t plugin = {
 static int request(ddns_t *ctx, ddns_info_t *info, ddns_alias_t *alias)
 {
 	return snprintf(ctx->request_buf, ctx->request_buflen,
-			GIRADNS_UPDATE_IP_HTTP_REQUEST,
+			info->system->server_req,
 			info->server_url,
 			info->creds.username,
 			info->creds.password,
@@ -74,12 +87,14 @@ static int response(http_trans_t *trans, ddns_info_t *info, ddns_alias_t *alias)
 
 PLUGIN_INIT(plugin_init)
 {
-	plugin_register(&plugin);
+	plugin_register(&plugin, GIRADNS_UPDATE_IP_HTTP_REQUEST);
+	plugin_register(&plugin_v6, GIRADNS_UPDATE_IP_HTTP_REQUEST);
 }
 
 PLUGIN_EXIT(plugin_exit)
 {
 	plugin_unregister(&plugin);
+	plugin_unregister(&plugin_v6);
 }
 
 /**
