@@ -59,13 +59,13 @@ static int local_set_params(http_t *client)
 	return 0;
 }
 
-int http_init(http_t *client, char *msg)
+int http_init(http_t *client, char *msg, int force)
 {
 	int rc = 0;
 
 	do {
 		TRY(local_set_params(client));
-		TRY(ssl_open(client, msg));
+		TRY(ssl_open(client, msg, force));
 	}
 	while (0);
 
