@@ -1,6 +1,6 @@
 /* Custom error logging system
  *
- * Copyright (C) 2010-2020  Joachim Nilsson <troglobit@gmail.com>
+ * Copyright (C) 2010-2021  Joachim Wiberg <troglobit@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -77,7 +77,7 @@ void vlogit(int prio, const char *fmt, va_list args)
 		vfprintf(stderr, fmt, args), fprintf(stderr, "\n");
 }
 
-void logit(int prio, const char *fmt, ...)
+void logitf(int prio, const char *fmt, ...)
 {
 	va_list args;
 
